# MAGOT2
## Multitool for Analyzing Genomes or Transcriptomes II
### New, simpler toolkit for random common genomic analyses
A complete overhaul of the MAGOT toolkit. It will be a while before all functionality is ported over, but in the end it will be *so* much simpler and more elegantly written (and pip-installable).

## Instalation instructions:
```
pip install git+https://github.com/biorover/MAGOT2.git
```

## Usage:
```
#For list of subcommands, call:
MAGOT -h

#for subcommand help, call:
MAGOT <subcommand> -h
```